==> avidemux-cli-2.7.4-3-aarch64.pkg.tar.xz: usr/include/avidemux/2.7/ADM_coreUtils/prefs2_list.h <==
VERSION_APIVERSION, 	//uint32_t
FEATURES_SWAP_IF_A_GREATER_THAN_B, 	//bool
FEATURES_SAVEPREFSONEXIT, 	//bool
FEATURES_IGNORESAVEDMARKERS, 	//bool
FEATURES_REUSE_2PASS_LOG, 	//bool
FEATURES_AUDIOBAR_USES_MASTER, 	//bool
FEATURES_THREADING_LAVC, 	//uint32_t
FEATURES_CPU_CAPS, 	//uint32_t
FEATURES_CACHE_SIZE, 	//uint32_t
FEATURES_MPEG_NO_LIMIT, 	//bool
FEATURES_DXVA2, 	//bool
FEATURES_DXVA2_OVERRIDE_BLACKLIST_VERSION, 	//bool
FEATURES_DXVA2_OVERRIDE_BLACKLIST_PROFILE, 	//bool
FEATURES_VDPAU, 	//bool
FEATURES_XVBA, 	//bool
FEATURES_LIBVA, 	//bool
FEATURES_VIDEOTOOLBOX, 	//bool
FEATURES_ENABLE_OPENGL, 	//bool
FEATURES_CAP_REFRESH_ENABLED, 	//bool
FEATURES_CAP_REFRESH_VALUE, 	//uint32_t
FEATURES_SDLDRIVER, 	//string
FEATURES_USE_LAST_READ_DIR_AS_TARGET, 	//bool
FEATURES_COPY_MODE_SANITIZE_DTS, 	//bool
KEYBOARD_SHORTCUTS_USE_ALTERNATE_KBD_SHORTCUTS, 	//bool
KEYBOARD_SHORTCUTS_SWAP_UP_DOWN_KEYS, 	//bool
KEYBOARD_SHORTCUTS_ALT_MARK_A, 	//string
KEYBOARD_SHORTCUTS_ALT_MARK_B, 	//string
KEYBOARD_SHORTCUTS_ALT_RESET_MARKERS, 	//string
KEYBOARD_SHORTCUTS_ALT_GOTO_MARK_A, 	//string
KEYBOARD_SHORTCUTS_ALT_GOTO_MARK_B, 	//string
KEYBOARD_SHORTCUTS_ALT_BEGIN, 	//string
KEYBOARD_SHORTCUTS_ALT_END, 	//string
UPDATE_ENABLED, 	//bool
UPDATE_LASTCHECK, 	//uint32_t
LASTFILES_LASTDIR_READ, 	//string
LASTFILES_LASTDIR_WRITE, 	//string
LASTFILES_FILE1, 	//string
LASTFILES_FILE2, 	//string
LASTFILES_FILE3, 	//string
LASTFILES_FILE4, 	//string
LASTPROJECTS_LASTDIR_READ, 	//string
LASTPROJECTS_LASTDIR_WRITE, 	//string
LASTPROJECTS_FILE1, 	//string
LASTPROJECTS_FILE2, 	//string
LASTPROJECTS_FILE3, 	//string
LASTPROJECTS_FILE4, 	//string
MESSAGE_LEVEL, 	//uint32_t
AUDIO_DEVICE_AUDIODEVICE, 	//string
AUDIO_DEVICE_ALSA_DEVICE, 	//string
VIDEODEVICE, 	//uint32_t
PRIORITY_ENCODING, 	//uint32_t
PRIORITY_INDEXING, 	//uint32_t
PRIORITY_PLAYBACK, 	//uint32_t
DEFAULT_POSTPROC_TYPE, 	//uint32_t
DEFAULT_POSTPROC_VALUE, 	//uint32_t
DEFAULT_DOWNMIXING, 	//uint32_t
DEFAULT_LANGUAGE, 	//string
DEFAULT_WARN_FOR_FONTS, 	//bool
AVISYNTH_AVISYNTH_ALWAYS_ASK, 	//bool
AVISYNTH_AVISYNTH_DEFAULTPORT, 	//uint32_t
AVISYNTH_AVISYNTH_LOCALPORT, 	//uint32_t
RESET_ENCODER_ON_VIDEO_LOAD, 	//bool

==> avidemux-cli-2.8.1-4-aarch64.pkg.tar.xz: usr/include/avidemux/2.8/ADM_coreUtils/prefs2_list.h <==
VERSION_APIVERSION, 	//uint32_t
FEATURES_SWAP_IF_A_GREATER_THAN_B, 	//bool
FEATURES_SAVEPREFSONEXIT, 	//bool
FEATURES_IGNORESAVEDMARKERS, 	//bool
FEATURES_REUSE_2PASS_LOG, 	//bool
FEATURES_AUDIOBAR_USES_MASTER, 	//bool
FEATURES_THREADING_LAVC, 	//uint32_t
FEATURES_CPU_CAPS, 	//uint32_t
FEATURES_CACHE_SIZE, 	//uint32_t
FEATURES_SHARED_CACHE, 	//bool
FEATURES_MPEG_NO_LIMIT, 	//bool
FEATURES_DXVA2, 	//bool
FEATURES_DXVA2_OVERRIDE_BLACKLIST_VERSION, 	//bool
FEATURES_DXVA2_OVERRIDE_BLACKLIST_PROFILE, 	//bool
FEATURES_VDPAU, 	//bool
FEATURES_XVBA, 	//bool
FEATURES_LIBVA, 	//bool
FEATURES_VIDEOTOOLBOX, 	//bool
FEATURES_ENABLE_OPENGL, 	//bool
FEATURES_FILTER_PREVIEW_CANVAS_OPENGL, 	//bool
FEATURES_CAP_REFRESH_ENABLED, 	//bool
FEATURES_CAP_REFRESH_VALUE, 	//uint32_t
FEATURES_SDLDRIVER, 	//string
FEATURES_USE_LAST_READ_DIR_AS_TARGET, 	//bool
FEATURES_SWAP_MOUSE_WHEEL, 	//bool
KEYBOARD_SHORTCUTS_USE_ALTERNATE_KBD_SHORTCUTS, 	//bool
KEYBOARD_SHORTCUTS_SWAP_UP_DOWN_KEYS, 	//bool
KEYBOARD_SHORTCUTS_ALT_MARK_A, 	//string
KEYBOARD_SHORTCUTS_ALT_MARK_B, 	//string
KEYBOARD_SHORTCUTS_ALT_RESET_MARK_A, 	//string
KEYBOARD_SHORTCUTS_ALT_RESET_MARK_B, 	//string
KEYBOARD_SHORTCUTS_ALT_RESET_MARKERS, 	//string
KEYBOARD_SHORTCUTS_ALT_GOTO_MARK_A, 	//string
KEYBOARD_SHORTCUTS_ALT_GOTO_MARK_B, 	//string
KEYBOARD_SHORTCUTS_ALT_BEGIN, 	//string
KEYBOARD_SHORTCUTS_ALT_END, 	//string
KEYBOARD_SHORTCUTS_ALT_DELETE, 	//string
UPDATE_ENABLED, 	//bool
UPDATE_LASTCHECK, 	//uint32_t
LASTFILES_LASTDIR_READ, 	//string
LASTFILES_LASTDIR_WRITE, 	//string
LASTFILES_FILE1, 	//string
LASTFILES_FILE2, 	//string
LASTFILES_FILE3, 	//string
LASTFILES_FILE4, 	//string
LASTPROJECTS_LASTDIR_READ, 	//string
LASTPROJECTS_LASTDIR_WRITE, 	//string
LASTPROJECTS_FILE1, 	//string
LASTPROJECTS_FILE2, 	//string
LASTPROJECTS_FILE3, 	//string
LASTPROJECTS_FILE4, 	//string
MESSAGE_LEVEL, 	//uint32_t
AUDIO_DEVICE_AUDIODEVICE, 	//string
AUDIO_DEVICE_ALSA_DEVICE, 	//string
VIDEODEVICE, 	//uint32_t
PRIORITY_ENCODING, 	//uint32_t
PRIORITY_PLAYBACK, 	//uint32_t
DEFAULT_POSTPROC_TYPE, 	//uint32_t
DEFAULT_POSTPROC_VALUE, 	//uint32_t
DEFAULT_DOWNMIXING, 	//uint32_t
DEFAULT_LANGUAGE, 	//string
DEFAULT_WARN_FOR_FONTS, 	//bool
DEFAULT_MULTILOAD_USE_CUSTOM_SIZE, 	//bool
DEFAULT_MULTILOAD_CUSTOM_SIZE_M, 	//uint32_t
DEFAULT_DELETE_FIRST_PASS_LOG_FILES, 	//bool
AVISYNTH_AVISYNTH_ALWAYS_ASK, 	//bool
AVISYNTH_AVISYNTH_DEFAULTPORT, 	//uint32_t
AVISYNTH_AVISYNTH_LOCALPORT, 	//uint32_t
RESET_ENCODER_ON_VIDEO_LOAD, 	//bool
PICTURES_LOAD_IN_REVERSE_ORDER, 	//bool
PICTURES_FPS_TYPE, 	//uint32_t
HDR_TONEMAPPING, 	//uint32_t
HDR_TARGET_LUMINANCE, 	//float
HDR_OUT_OF_GAMUT_HANDLING, 	//uint32_t
